server_client_20141211_175217

### config1 : test_client_isolation

Result | Function execution time | Total execution time
--- | --- | ---
Failed | 2.26763105392 sec | 5.4663541317 sec

Error message: Did not properly handle faulty client

Naarad report

### Metrics

#### server1-perf

Submetric | max | mean | min | p50 | p75 | p90 | p95 | p99 | std
--- | --- | --- | --- | --- | --- | --- | --- | --- | ---
latency | 0.84 | 0.32 | 0.22 | 0.3 | 0.37 | 0.42 | 0.48 | 0.75 | 0.096
qps | 207.00 | 185.50 | 164.00 | 185.50 | 196.25 | 202.70 | 204.85 | 206.57 | 21.50

### SLAs

metric | submetric | sla rule | value
--- | --- | --- | ---
server1-perf | latency | p50 lt 0.3 | 0.302
server1-perf | latency | mean lt 0.33 | 0.323633423181
server1-perf | qps | mean lt 7.0 | 185.5
server2-perf | latency | p50 lt 0.3 | None
server2-perf | latency | mean lt 0.33 | None
server2-perf | qps | mean lt 7.0 | None
server3-perf | latency | p50 lt 0.3 | None
server3-perf | latency | mean lt 0.33 | None
server3-perf | qps | mean lt 7.0 | None
client1-perf | latency | p50 lt 22.0 | None
client1-perf | latency | mean lt 35.0 | None
client1-perf | qps | mean lt 2.0 | None
client2-perf | latency | p50 lt 22.0 | None
client2-perf | latency | mean lt 35.0 | None
client2-perf | qps | mean lt 2.0 | None